@@ -6,11 +6,11 @@ from rich.logging import RichHandler
 from autosbatch.autosbatch import SlurmPool
 
 logging.basicConfig(
-    level=logging.INFO,
+    level=logging.WARNING,
     format="%(message)s",
     datefmt="[%X]",
     handlers=[RichHandler(rich_tracebacks=True, show_path=False)],
 )
 __author__ = """Jianhua Wang"""
 __email__ = 'jianhua.mert@gmail.com'
-__version__ = '0.2.1'
+__version__ = '0.2.2'
